@@ -57,7 +57,14 @@ def getInkeyData(videoSeq, session=None, silent=False):
     sr = reqWrapper.get(gv.APIInkeyUrl(videoSeq), headers=headers, wait=0.5, session=session, status=[200])
 
     if sr.success:
-        return sr.response.json()
+        parsed_json = sr.response.json()
+        if "code" in parsed_json:
+            if "result" in parsed_json:
+                return parsed_json['result']
+            else:
+                return None
+        else:
+            return parsed_json
     else:
         auto_raise(APINetworkError, silent)
 
@@ -100,7 +107,14 @@ def getPostInfo(post, session=None, silent=False):
     sr = reqWrapper.get(gv.APIPostUrl(post), headers=headers, wait=0.5, session=session, status=[200, 403])
 
     if sr.success:
-        return sr.response.json()
+        parsed_json = sr.response.json()
+        if "code" in parsed_json:
+            if "result" in parsed_json:
+                return parsed_json['result']
+            else:
+                return None
+        else:
+            return parsed_json
     else:
         auto_raise(APINetworkError, silent)
 
@@ -122,7 +136,14 @@ def getOfficialVideoPost(videoSeq, session=None, silent=False):
                         session=session, wait=0.5, status=[200, 403])
 
     if sr.success:
-        return sr.response.json()
+        parsed_json = sr.response.json()
+        if "code" in parsed_json:
+            if "result" in parsed_json:
+                return parsed_json['result']
+            else:
+                return None
+        else:
+            return parsed_json
     else:
         auto_raise(APINetworkError, silent)
 
@@ -156,7 +177,14 @@ def getLivePlayInfo(videoSeq, session=None, vpdid2=None, silent=False):
     sr = reqWrapper.get(url, headers=headers, session=session, status=[200, 403])
 
     if sr.success:
-        return sr.response.json()
+        parsed_json = sr.response.json()
+        if "code" in parsed_json:
+            if "result" in parsed_json:
+                return parsed_json['result']
+            else:
+                return None
+        else:
+            return parsed_json
     else:
         auto_raise(APINetworkError, silent)
 
@@ -177,7 +205,14 @@ def getLiveStatus(videoSeq, silent=False):
     sr = reqWrapper.get(gv.APILiveV2StatusUrl(videoSeq), headers=headers, wait=0.2, status=[200])
 
     if sr.success:
-        return sr.response.json()
+        parsed_json = sr.response.json()
+        if "code" in parsed_json:
+            if "result" in parsed_json:
+                return parsed_json['result']
+            else:
+                return None
+        else:
+            return parsed_json
     else:
         auto_raise(APINetworkError, silent)
 
@@ -212,7 +247,14 @@ def getVodPlayInfo(videoSeq, vodId=None, session=None, silent=False):
     sr = reqWrapper.get(url, headers=headers, session=session, wait=0.3, status=[200, 403])
 
     if sr.success:
-        return sr.response.json()
+        parsed_json = sr.response.json()
+        if "code" in parsed_json:
+            if "result" in parsed_json:
+                return parsed_json['result']
+            else:
+                return None
+        else:
+            return parsed_json
     else:
         auto_raise(APINetworkError, silent=silent)
 
